@@ -76,7 +76,11 @@ impl Api {
         state: v0::CreateStateDto,
         params: Vec<(String, String)>,
     ) -> ApiResult<v0::State> {
-        self.post("/states", state, &params).await
+        let mut state = json::to_value(&state)?;
+        if !params.is_empty() {
+            state["replixParams"] = params.into_iter().collect::<json::Value>();
+        }
+        self.post("/states", state).await
     }
 
     pub(crate) async fn create_volume(
@@ -85,7 +89,7 @@ impl Api {
         volume: v0::CreateVolumeDto,
     ) -> ApiResult<v0::Volume> {
         let path = format!("/states/{state_name}/volumes", state_name = state_name);
-        self.post(path, volume, &[]).await
+        self.post(path, volume).await
     }
 
     pub(crate) async fn delete_volume(
@@ -173,7 +177,7 @@ impl Api {
             provider,
             locations,
         };
-        self.post("/clusters", body, &[]).await
+        self.post("/clusters", body).await
     }
 
     pub(crate) async fn unregister_cluster(&self, name: &v0::ClusterName) -> ApiResult<()> {
@@ -201,7 +205,7 @@ impl Api {
     ) -> ApiResult<v0::StateLocationAws> {
         let path = format!("/states/{name}/locations/aws", name = name);
         let body = v0::CreateStateLocationAwsDto { region };
-        self.post(path, body, &[]).await
+        self.post(path, body).await
     }
 
     pub(crate) async fn del_aws_location(
@@ -237,7 +241,7 @@ impl Api {
     ) -> ApiResult<v0::StateLocationAzure> {
         let path = format!("/states/{name}/locations/azure", name = name);
         let body = v0::CreateStateLocationAzureDto { region };
-        self.post(path, body, &[]).await
+        self.post(path, body).await
     }
 
     pub(crate) async fn del_azure_location(
@@ -276,14 +280,14 @@ impl Api {
         cluster: &v0::ClusterName,
     ) -> ApiResult<v0::ClusterToken> {
         let path = format!("/clusters/{}/token", cluster);
-        self.post::<_, _, (), _>(path, None, &[]).await
+        self.post::<_, _, (), _>(path, None).await
     }
 
     pub(crate) async fn report_event<T>(&self, event: &v0::Report<T>) -> ApiResult<()>
     where
         T: ser::Serialize,
     {
-        self.post("/events", event, &[]).await
+        self.post("/events", event).await
     }
 
     pub(crate) fn url(&self, path: impl fmt::Display) -> String {
@@ -344,7 +348,7 @@ impl Api {
             .inspect(|output| self.inspect(output))
     }
 
-    async fn post<P, B, T, U>(&self, path: P, body: B, query: &[(String, String)]) -> ApiResult<U>
+    async fn post<P, B, T, U>(&self, path: P, body: B) -> ApiResult<U>
     where
         P: fmt::Display,
         B: Into<Option<T>>,
@@ -355,7 +359,6 @@ impl Api {
         let url = self.url(path);
         self.client()?
             .post(url)
-            .query(query)
             .optionally_bearer_auth(self.token.as_ref())
             .inspect()
             .optionally_json(body.as_ref())
