@@ -122,11 +122,19 @@ impl Config {
         }
     }
 
-    pub(crate) fn save(&self) -> anyhow::Result<PathBuf> {
+    pub(crate) fn save(&self, set_default_profile: bool) -> anyhow::Result<PathBuf> {
         let dir = Self::statehub_home()?;
         fs::create_dir_all(dir).context("Creating config filesystem hierarchy")?;
         let path = Self::config_file()?;
-        let contents = toml::to_string_pretty(&self.config).context("Serializing config")?;
+
+        let mut config = self.config.clone();
+        if set_default_profile {
+            if let Some(ref profile) = self.profile {
+                config.set_profile(profile);
+            }
+        }
+
+        let contents = toml::to_string_pretty(&config).context("Serializing config")?;
         fs::write(&path, contents)
             .context("Writing config")
             .map(|_| path)
